summaryrefslogtreecommitdiff
path: root/src/include/cpu
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/cpu')
-rw-r--r--src/include/cpu/x86/smm.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/include/cpu/x86/smm.h b/src/include/cpu/x86/smm.h
index 37247ece49..8ea8336a2d 100644
--- a/src/include/cpu/x86/smm.h
+++ b/src/include/cpu/x86/smm.h
@@ -120,7 +120,7 @@ static inline bool smm_points_to_smram(const void *ptr, const size_t len)
/* SMM Module Loading API */
/* The smm_loader_params structure provides direction to the SMM loader:
* - num_concurrent_stacks - number of concurrent cpus in handler needing stack
* optional for setting up relocation handler.
* - per_cpu_save_state_size - the SMM save state size per cpu
* - num_concurrent_save_states - number of concurrent cpus needing save state
@@ -132,7 +132,7 @@ static inline bool smm_points_to_smram(const void *ptr, const size_t len)
* handle sparse APIC id space.
*/
struct smm_loader_params {
- size_t num_concurrent_stacks;
+ size_t num_cpus;
size_t real_cpu_save_state_size;
size_t per_cpu_save_state_size;
@@ -120,7 +120,7 @@ static inline bool smm_points_to_smram(const void *ptr, const size_t len)
/* SMM Module Loading API */
/* The smm_loader_params structure provides direction to the SMM loader:
- * - num_concurrent_stacks - number of concurrent cpus in handler needing stack
+ * - num_cpus - number of concurrent cpus in handler needing stack
* optional for setting up relocation handler.
* - per_cpu_save_state_size - the SMM save state size per cpu